"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defineRule = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
const UNEXPECTED_ERROR_LOCATION = { line: 1, column: 0 };
function defineRule(ruleName, rule) {
    return {
        meta: Object.assign(Object.assign({}, rule.meta), { docs: Object.assign(Object.assign({}, rule.meta.docs), { url: 'https://github.com/intlify/eslint-plugin-svelte/blob/main/docs/rules/' +
                    ruleName +
                    '.md' }) }),
        create(context) {
            if (!context.parserServices.isSvelte) {
                const filename = context.getFilename();
                if (isSvelteFile(filename)) {
                    context.report({
                        loc: UNEXPECTED_ERROR_LOCATION,
                        message: 'Use the latest svelte-eslint-parser. See also https://github.com/intlify/eslint-plugin-svelte/blob/main/docs/started.md#faq'
                    });
                }
                return {};
            }
            return rule.create(context);
        }
    };
}
exports.defineRule = defineRule;
function isSvelteFile(filename) {
    if (!filename.includes('.svelte')) {
        return false;
    }
    let target = filename;
    while (!fs_1.existsSync(target)) {
        const next = path_1.dirname(target);
        if (!next || next === target) {
            return false;
        }
        target = next;
    }
    return path_1.extname(target) === '.svelte';
}
